@@ -5,27 +5,25 @@
 */
 
 #include "exportdialog.h"
-#include "fileviewhgpluginsettings.h"
 #include "commitinfowidget.h"
+#include "fileviewhgpluginsettings.h"
 #include "hgwrapper.h"
 
-#include <QCheckBox>
-#include <QGroupBox>
-#include <QVBoxLayout>
-#include <QGridLayout>
-#include <QListWidget>
-#include <QProcess>
-#include <QTextCodec>
-#include <QFileDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QCheckBox>
+#include <QFileDialog>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QListWidget>
+#include <QProcess>
+#include <QVBoxLayout>
 
-HgExportDialog::HgExportDialog(QWidget *parent) :
-    DialogBase(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, parent)
+HgExportDialog::HgExportDialog(QWidget *parent)
+    : DialogBase(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, parent)
 {
     // dialog properties
-    this->setWindowTitle(i18nc("@title:window",
-                "<application>Hg</application> Export"));
+    this->setWindowTitle(i18nc("@title:window", "<application>Hg</application> Export"));
     okButton()->setText(xi18nc("@action:button", "Export"));
 
     //
@@ -34,8 +32,7 @@ HgExportDialog::HgExportDialog(QWidget *parent) :
 
     // Load saved settings
     FileViewHgPluginSettings *settings = FileViewHgPluginSettings::self();
-    this->resize(QSize(settings->exportDialogWidth(),
-                               settings->exportDialogHeight()));
+    this->resize(QSize(settings->exportDialogWidth(), settings->exportDialogHeight()));
 
     //
     connect(this, SIGNAL(finished(int)), this, SLOT(saveGeometry()));
@@ -62,7 +59,7 @@ void HgExportDialog::setupUI()
     optionLayout->addWidget(m_optNoDates);
     m_optionGroup->setLayout(optionLayout);
 
-    //setup main dialog widget
+    // setup main dialog widget
     QVBoxLayout *lay = new QVBoxLayout;
     lay->addWidget(mainGroup);
     lay->addWidget(m_optionGroup);
@@ -80,8 +77,9 @@ void HgExportDialog::loadCommits()
     QStringList args;
     args << QLatin1String("log");
     args << QLatin1String("--template");
-    args << QLatin1String("{rev}\n{node|short}\n{branch}\n"
-                          "{author}\n{desc|firstline}\n");
+    args << QLatin1String(
+        "{rev}\n{node|short}\n{branch}\n"
+        "{author}\n{desc|firstline}\n");
 
     process.start(QLatin1String("hg"), args);
     process.waitForFinished();
@@ -92,11 +90,11 @@ void HgExportDialog::loadCommits()
     int count = 0;
     while (process.readLine(buffer[count], sizeof(buffer[count])) > 0) {
         if (count == FINAL - 1) {
-            QString rev = QTextCodec::codecForLocale()->toUnicode(buffer[0]).trimmed();
-            QString changeset = QTextCodec::codecForLocale()->toUnicode(buffer[1]).trimmed();
-            QString branch = QTextCodec::codecForLocale()->toUnicode(buffer[2]).trimmed();
-            QString author = QTextCodec::codecForLocale()->toUnicode(buffer[3]).trimmed();
-            QString log = QTextCodec::codecForLocale()->toUnicode(buffer[4]).trimmed();
+            QString rev = QString::fromLocal8Bit(buffer[0]).trimmed();
+            QString changeset = QString::fromLocal8Bit(buffer[1]).trimmed();
+            QString branch = QString::fromLocal8Bit(buffer[2]).trimmed();
+            QString author = QString::fromLocal8Bit(buffer[3]).trimmed();
+            QString log = QString::fromLocal8Bit(buffer[4]).trimmed();
 
             QListWidgetItem *item = new QListWidgetItem;
             item->setData(Qt::DisplayRole, changeset);
@@ -106,7 +104,7 @@ void HgExportDialog::loadCommits()
             item->setData(Qt::UserRole + 4, log);
             m_commitInfoWidget->addItem(item);
         }
-        count = (count + 1)%FINAL;
+        count = (count + 1) % FINAL;
     }
 }
 
@@ -121,10 +119,9 @@ void HgExportDialog::saveGeometry()
 void HgExportDialog::done(int r)
 {
     if (r == QDialog::Accepted) {
-        const QList<QListWidgetItem*> items = m_commitInfoWidget->selectedItems();
+        const QList<QListWidgetItem *> items = m_commitInfoWidget->selectedItems();
         if (items.empty()) {
-            KMessageBox::error(this, i18nc("@message:error",
-                     "Please select at least one changeset to be exported!"));
+            KMessageBox::error(this, i18nc("@message:error", "Please select at least one changeset to be exported!"));
             return;
         }
 
@@ -158,16 +155,12 @@ void HgExportDialog::done(int r)
         HgWrapper *hgw = HgWrapper::instance();
         if (hgw->executeCommandTillFinished(QStringLiteral("export"), args)) {
             QDialog::done(r);
-        }
-        else {
+        } else {
             KMessageBox::error(this, hgw->readAllStandardError());
         }
-    }
-    else {
+    } else {
         QDialog::done(r);
     }
 }
 
-
-
 #include "moc_exportdialog.cpp"
